==> vercel-submodules-1.0.8.tgz: package/lib/commands/clone.js <==
import chalk from 'chalk';
import GitUrlParse from 'git-url-parse';
import path from 'path';
import * as zx from 'zx';
import { insideDir } from '../utils/filesystem.js';
const convertToAuthURL = ({ url, githubToken, isFineGrained }) => {
    const parsed = GitUrlParse(url);
    parsed.token = isFineGrained ? `oauth2:${githubToken}` : githubToken;
    return GitUrlParse.stringify(parsed, 'https');
};
export const clone = async ({ githubToken, isFineGrained, depth, submodules }) => {
    const topLevel = (await zx.$ `git rev-parse --show-toplevel`).stdout.trim();
    for (const submodule of submodules) {
        const submoduleDir = path.join(topLevel, submodule.gitModulePath);
        const submoduleURL = !githubToken
            ? submodule.url
            : convertToAuthURL({
                url: submodule.url,
                githubToken,
                isFineGrained,
            });
        await zx.$ `rm -rf ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await zx.$ `mkdir ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await insideDir(submoduleDir, async () => {
            await zx.$ `git init`;
            try {
                await zx.$ `git remote add origin ${submoduleURL}`;
            }
            catch (_a) {
                await zx.$ `git remote set-url origin ${submoduleURL}`;
            }
            await zx.$ `git fetch origin ${submodule.commitHash} --depth=${depth} --no-tags`;
            await zx.$ `git reset --hard FETCH_HEAD`;
        });
        console.log(`${chalk.green('Clone Success')} Submodule ${chalk.cyan(`${submodule.path}@${submodule.commitHash.slice(0, 7)}`)}`);
    }
};

==> vercel-submodules-1.0.10.tgz: package/lib/commands/clone.js <==
import chalk from 'chalk';
import GitUrlParse from 'git-url-parse';
import path from 'path';
import * as zx from 'zx';
import { insideDir } from '../utils/filesystem.js';
const convertToAuthURL = ({ url, githubToken, isFineGrained }) => {
    const parsed = GitUrlParse(url);
    parsed.token = isFineGrained ? `oauth2:${githubToken}` : githubToken;
    return GitUrlParse.stringify(parsed, 'https');
};
export const clone = async ({ githubToken, isFineGrained, depth, submodules }) => {
    const topLevel = (await zx.$ `git rev-parse --show-toplevel`).stdout.trim();
    for (const submodule of submodules) {
        const submoduleDir = path.join(topLevel, submodule.gitModulePath);
        const submoduleURL = !githubToken
            ? submodule.url
            : convertToAuthURL({
                url: submodule.url,
                githubToken,
                isFineGrained,
            });
        await zx.$ `rm -rf ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await zx.$ `mkdir ${submoduleDir}`.catch(() => {
            /* ignored */
        });
        await insideDir(submoduleDir, async () => {
            await zx.$ `git init`;
            try {
                await zx.$ `git remote add origin ${submoduleURL}`;
            }
            catch (_a) {
                await zx.$ `git remote set-url origin ${submoduleURL}`;
            }
            await zx.$ `git fetch origin ${submodule.branch || submodule.commitHash} --depth=${depth} --no-tags`;
            await zx.$ `git reset --hard FETCH_HEAD`;
        });
        console.log(`${chalk.green('Clone Success')} Submodule ${chalk.cyan(`${submodule.path}@${submodule.commitHash.slice(0, 7)}`)}`);
    }
};
